@@ -3,6 +3,8 @@ package HTML::FormatText::WithLinks::AndTables;
 use strict;
 use warnings;
 
+our $VERSION = '0.06'; # VERSION
+
 use base 'HTML::FormatText::WithLinks';
 use HTML::TreeBuilder;
 
@@ -19,7 +21,7 @@ HTML::FormatText::WithLinks::AndTables - Converts HTML to Text with tables intac
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =cut
 
@@ -83,7 +85,10 @@ sub convert {
 
 # sub-class configure
 sub configure {
-    shift()->SUPER::configure($conf_defaults);
+# SUPER::configure actually modifies the hash, so we need to pass a copy
+    my %configure = %$conf_defaults;
+
+    shift()->SUPER::configure(\%configure);
 }
 
 # sub-class parse
